# file generated by setuptools_scm
# don't change, don't track in version control
__version__ = version = '0.0.14.dev6+g259f83b.d20230327'
__version_tuple__ = version_tuple = (0, 0, 14, 'dev6', 'g259f83b.d20230327')
